@@ -13,6 +13,7 @@ import zipfile
 import shutil
 import click
 import gzip
+import ssl
 import os
 __author__ = 'adamkoziol'
 
@@ -30,6 +31,9 @@ class DatabaseSetup(object):
             self.cowbat_targets(databasepath=self.databasepath)
         if self.overwrite or not os.path.isdir(os.path.join(self.databasepath, 'ConFindr')):
             self.confindr_targets()
+        if self.overwrite or not os.path.isdir(os.path.join(self.databasepath, 'rMLST')):
+            self.rmlst(databasepath=self.databasepath,
+                       credentials=self.credentials)
         if self.overwrite or not os.path.isdir(os.path.join(self.databasepath, 'mash')):
             self.mash(databasepath=self.databasepath)
         if self.overwrite or not os.path.isdir(os.path.join(self.databasepath, 'MLST')):
@@ -40,11 +44,8 @@ class DatabaseSetup(object):
                 self.mlst(databasepath=self.databasepath,
                           genera=('Bacillus', 'Campylobacter', 'Cronobacter', 'Escherichia', 'Listeria',
                                   'Salmonella', 'Staphylococcus', 'Vibrio', 'Yersinia'))
-        if self.overwrite or not os.path.isdir(os.path.join(self.databasepath, 'rMLST')):
-            self.rmlst(databasepath=self.databasepath,
-                       credentials=self.credentials)
-        if self.overwrite or not os.path.isdir(os.path.join(self.databasepath, 'cgMLST')):
-            self.enterobase_cgmlst(databasepath=self.databasepath)
+        # if self.overwrite or not os.path.isdir(os.path.join(self.databasepath, 'cgMLST')):
+        #     self.enterobase_cgmlst(databasepath=self.databasepath)
         if self.overwrite or not os.path.isdir(os.path.join(self.databasepath, 'univec')):
             self.univec(databasepath=self.databasepath)
         if self.overwrite or not os.path.isdir(os.path.join(self.databasepath, 'resfinder')):
@@ -63,8 +64,8 @@ class DatabaseSetup(object):
             self.cge_db_downloader(databasepath=self.databasepath,
                                    analysistype='pointfinder',
                                    dbname='pointfinder_db')
-        if self.overwrite or not os.path.isdir(os.path.join(self.databasepath, 'clark')):
-            self.clark(databasepath=self.databasepath)
+        # if self.overwrite or not os.path.isdir(os.path.join(self.databasepath, 'clark')):
+        #     self.clark(databasepath=self.databasepath)
         self.download_date()
 
     def sipprverse_full(self):
@@ -127,7 +128,7 @@ class DatabaseSetup(object):
                               database_name=database_name,
                               download_id=download_id)
 
-    def cowbat_targets(self, databasepath, database_name='COWBAT', download_id='18130850'):
+    def cowbat_targets(self, databasepath, database_name='COWBAT', download_id='25319129'):
         """
         Download OLC-specific COWBAT targets
         :param databasepath: path to use to save the database
@@ -153,7 +154,8 @@ class DatabaseSetup(object):
         call(condfindr_download, shell=True)
 
     @staticmethod
-    def mlst(databasepath, genera=('Campylobacter', 'Cronobacter', 'Listeria',
+    def mlst(databasepath, genera=('Escherichia', 'Salmonella', 'Yersinia',
+                                   'Campylobacter', 'Cronobacter', 'Listeria',
                                    'Bacillus', 'Staphylococcus', 'Vibrio')):
         """
         Download the necessary up-to-date MLST profiles and alleles from pubmlst
@@ -206,7 +208,9 @@ class DatabaseSetup(object):
                     scheme=scheme,
                     db=databasepath)
         if not os.path.isdir(os.path.join(databasepath, analysis, genus)):
-            call(enterobase_cmd, shell=True)
+            #call(enterobase_cmd, shell=True)
+            out, err = run_subprocess(enterobase_cmd)
+            print(out, err)
 
     @staticmethod
     def rmlst(databasepath, credentials):
@@ -238,7 +242,7 @@ class DatabaseSetup(object):
         :param databasepath: path to use to save the database
         :param genera: default genera for which alleles and profiles should be downloaded
         """
-        logging.info('Downloading MLST databases from Enterobase')
+        logging.info('Downloading cMLST databases from Enterobase')
         for genus in genera:
             self.enterobase_download(scheme='cgMLST',
                                      databasepath=databasepath,
@@ -291,7 +295,7 @@ class DatabaseSetup(object):
         if not os.path.isfile(output_file):
             self.database_download(output_file=output_file,
                                    database_path=databasepath,
-                                   target_url='https://gembox.cbcb.umd.edu/mash/refseq.genomes.k21s1000.msh',
+                                   target_url='https://obj.umiacs.umd.edu/marbl_publications/mash/refseq.genomes.k21s1000.msh',
                                    complete=True)
 
     def univec(self, databasepath):
@@ -313,15 +317,17 @@ class DatabaseSetup(object):
             shutil.copy(outputfile, renamed)
 
     @staticmethod
-    def url_request(target_url, output_file):
+    def url_request(target_url, output_file, context):
         """
         Use urllib to download the requested file from the target URL. Use the click progress bar to print download
         progress
         :param target_url: URL from which the file is to be downloaded
         :param output_file: Name and path of local copy of file
+        :param context: ssl.create_default_context() with check_hostname set to False, and verify_mode 
+        set to ssl.CERT_NONE
         """
         # Create the request
-        request = urllib.request.urlopen(target_url)
+        request = urllib.request.urlopen(target_url, context=context)
         # Open the destination file to write
         with open(output_file, 'wb') as targets:
             # Calculate the total file size - will be used by the progress bar
@@ -372,7 +378,8 @@ class DatabaseSetup(object):
         logging.debug(target_url)
         if not os.path.isfile(completefile):
             self.url_request(target_url=target_url,
-                             output_file=tar_file)
+                             output_file=tar_file,
+                             context=self.context)
         # Decompress the file
         self.decompress(databasepath=databasepath,
                         database_name=database_name,
@@ -427,8 +434,6 @@ class DatabaseSetup(object):
         logging.info('Downloading {} database'.format(analysistype))
         if analysistype == 'serosippr':
             databasepath = os.path.join(databasepath, analysistype, 'Escherichia')
-        elif analysistype == 'resfinder':
-            databasepath = databasepath
         else:
             databasepath = os.path.join(databasepath, analysistype)
         targetcall = 'git clone https://bitbucket.org/genomicepidemiology/{db}.git {atype}'\
@@ -485,7 +490,8 @@ class DatabaseSetup(object):
         completefile = os.path.join(database_path, 'complete')
         if not os.path.isfile(completefile):
             self.url_request(target_url=target_url,
-                             output_file=output_file)
+                             output_file=output_file,
+                             context=self.context)
             if complete:
                 # Create the completefile
                 with open(completefile, 'w') as complete:
@@ -545,6 +551,10 @@ class DatabaseSetup(object):
             'Salmonella': 'senterica',
             'Yersinia': 'yersinia'
         }
+        # Create a context to all for disabling SSL verifying
+        self.context = ssl.create_default_context()
+        self.context.check_hostname = False
+        self.context.verify_mode = ssl.CERT_NONE
 
 
 # If the script is called from the command line, then call the argument parser
@@ -571,9 +581,9 @@ if __name__ == '__main__':
                         help='Optionally only download the databases used by the sipprverse method: genesippr, '
                              'sixteenS, GDCS, MASH, and ConFindr')
     parser.add_argument('-e', '--enterobase',
-                        action='store_false',
+                        action='store_true',
                         help='Use Enterobase to download MLST definitions for Escherichia, Salmonella, and Yersinia, '
-                             'as well as cgMLST schemes for Escherichia and Yersinia. Enabled by default')
+                             'as well as cgMLST schemes for Escherichia and Yersinia. Disabled by default')
     parser.add_argument('-v', '--verbose',
                         action='store_true',
                         help='Option to include debug level logging messages. Default is false')
