@@ -1,7 +1,11 @@
 #!/usr/bin/env python3
+from olctools.accessoryFunctions.accessoryFunctions import run_subprocess
+import selenium.common.exceptions
 from rauth import OAuth1Session
 import multiprocessing
+import subprocess
 import getpass
+import sys
 import os
 import re
 # import chromedriver_autoinstaller
@@ -158,12 +162,50 @@ class REST(object):
             login_user, login_pass = self.decrypt_credentials()
             if not login_user or login_pass:
                 login_user, login_pass = self.encrypt_credentials()
+        try:
+            verifier = self.selenium_authorise(authorize_url=authorize_url,
+                                               login_user=login_user,
+                                               login_pass=login_pass)
+        except selenium.common.exceptions.SessionNotCreatedException:
+            try:
+                # Attempt to install the correct version of chromedriver
+                run_subprocess('python -m pip install chromedriver-autoinstaller --trusted-host pypi.org '
+                               '--trusted-host files.pythonhosted.org --trusted-host pypi.python.org ')
+                import chromedriver_autoinstaller
+                chromedriver_autoinstaller.install()
+                verifier = self.selenium_authorise(authorize_url=authorize_url,
+                                                   login_user=login_user,
+                                                   login_pass=login_pass)
+            except (ModuleNotFoundError, selenium.common.exceptions.SessionNotCreatedException):
+                print('Visit this URL in your browser: ' + authorize_url)
+                # Use the user input to set the verifier code
+                verifier = input('Enter oauth_verifier from browser: ')
+        # Create a new session
+        session_request = OAuth1Session(consumer_key=self.consumer_key,
+                                        consumer_secret=self.consumer_secret,
+                                        access_token=self.request_token,
+                                        access_token_secret=self.request_secret)
+        # Perform a GET request with the appropriate keys and tokens
+        r = session_request.get(self.access_token_url,
+                                verify=False,
+                                params={
+                                    'oauth_verifier': verifier
+                                })
+        # If the status code is '200' (OK), proceed
+        if r.status_code == 200:
+            # Save the JSON-decoded token secret and token
+            self.access_token = r.json()['oauth_token']
+            self.access_secret = r.json()['oauth_token_secret']
+            # Write the token and secret to file
+            self.write_token('access_token', self.access_token, self.access_secret)
+
+    def selenium_authorise(self, authorize_url, login_user, login_pass):
 
         # Setup chrome options
         chrome_options = Options()
         chrome_options.add_argument("--headless")  # Ensure GUI is off
         chrome_options.add_argument("--no-sandbox")
-        
+        chrome_options.add_argument("ignore-certificate-errors")
         # Start up browser
         browser = webdriver.Chrome(options=chrome_options)
 
@@ -178,7 +220,14 @@ class REST(object):
         password = browser.find_element_by_name("password_field")
         password.clear()
         password.send_keys(login_pass)
-        
+        # If the cookie compliance element is present, it will intercept the login click
+        try:
+            cookie_dismiss = browser.find_element_by_class_name('cc-compliance')
+            cookie_dismiss.click()
+        except (selenium.common.exceptions.ElementNotInteractableException,
+                selenium.common.exceptions.NoSuchElementException,
+                selenium.common.exceptions.InvalidElementStateException):
+            pass
         login_button = browser.find_element_by_name("submit")
         login_button.click()
         authorize_button = browser.find_element_by_name("submit")
@@ -187,26 +236,9 @@ class REST(object):
         assert "Authorize third-party client" in browser.title
         code = browser.find_element_by_xpath("/html/body/div[2]/div[2]/div/div[2]/p[3]/b").get_attribute("innerHTML")
         verifier = code.split()[2]
-        browser.quit()    
+        browser.quit()
         print("Selenium Authorization Successful")
-
-        # Create a new session
-        session_request = OAuth1Session(consumer_key=self.consumer_key,
-                                        consumer_secret=self.consumer_secret,
-                                        access_token=self.request_token,
-                                        access_token_secret=self.request_secret)
-        # Perform a GET request with the appropriate keys and tokens
-        r = session_request.get(self.access_token_url,
-                                params={
-                                    'oauth_verifier': verifier
-                                })
-        # If the status code is '200' (OK), proceed
-        if r.status_code == 200:
-            # Save the JSON-decoded token secret and token
-            self.access_token = r.json()['oauth_token']
-            self.access_secret = r.json()['oauth_token_secret']
-            # Write the token and secret to file
-            self.write_token('access_token', self.access_token, self.access_secret)
+        return verifier
 
     def get_request_token(self):
         """
@@ -223,6 +255,7 @@ class REST(object):
         # Use the test URL in the GET request
         r = session.request(method='GET',
                             url=self.request_token_url,
+                            verify=False,
                             params={'oauth_callback': 'oob'})
         # If the status code is '200' (OK), proceed
         if r.status_code == 200:
@@ -249,7 +282,8 @@ class REST(object):
                                         access_token=self.access_token,
                                         access_token_secret=self.access_secret)
         # Perform a GET request with the appropriate keys and tokens
-        r = session_request.get(self.session_token_url)
+        r = session_request.get(self.session_token_url,
+                                verify=False)
         # If the status code is '200' (OK), proceed
         if r.status_code == 200:
             # Save the JSON-decoded token secret and token
@@ -310,7 +344,8 @@ class REST(object):
                                 access_token=self.session_token,
                                 access_token_secret=self.session_secret)
         # Use the test URL in the GET request
-        r = session.get(self.test_rest_url)
+        r = session.get(self.test_rest_url,
+                        verify=False)
         if r.status_code == 200 or r.status_code == 201:
             if re.search('json', r.headers['content-type'], flags=0):
                 decoded = r.json()
@@ -341,7 +376,8 @@ class REST(object):
                                     access_token=self.session_token,
                                     access_token_secret=self.session_secret)
             # The profile file is called profiles_csv on the server. Updated the URL appropriately
-            r = session.get(self.profile + '/1/profiles_csv')
+            r = session.get(self.profile + '/1/profiles_csv',
+                            verify=False)
             # On a successful GET request, parse the returned data appropriately
             if r.status_code == 200 or r.status_code == 201:
                 if re.search('json', r.headers['content-type'], flags=0):
@@ -361,7 +397,8 @@ class REST(object):
                                 access_token=self.session_token,
                                 access_token_secret=self.session_secret)
         # Use the URL for all loci determined above
-        r = session.get(self.loci)
+        r = session.get(self.loci,
+                        verify=False)
         if r.status_code == 200 or r.status_code == 201:
             if re.search('json', r.headers['content-type'], flags=0):
                 decoded = r.json()
@@ -404,7 +441,8 @@ class REST(object):
                                     access_token=self.session_token,
                                     access_token_secret=self.session_secret)
             # The allele file on the server is called alleles_fasta. Update the URL appropriately
-            r = session.get(url + '/alleles_fasta')
+            r = session.get(url + '/alleles_fasta',
+                            verify=False)
             if r.status_code == 200 or r.status_code == 201:
                 if re.search('json', r.headers['content-type'], flags=0):
                     decoded = r.json()
